<?php
/*
+--------------------------------------------------------------------------
|   Limiting Dates
|   =============================================
|   by Tom Moore (www.xekko.co.uk)
|   =============================================
+---------------------------------------------------------------------------
|   > Date started: 30th January
|
|	Will limit the dates/times on memberlist and profile. Admins/Super-Mod
|	aren't affected by the changes. Settings in the Member List group.
+--------------------------------------------------------------------------
*/
 
// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("memberlist_user", "limit_mlist");
$plugins->add_hook("member_profile_end", "limit_profile");

function limit_info()
{
	return array(
		"name"			=> "Limited Joined / Last Visit",
		"description"	=> "Hides time from the Joined / Last Visit colums in the Memberlist and Profile",
		"website"		=> "http://community.mybboard.net",
		"author"		=> "Tom.M",
		"authorsite"	=> "http://www.xekko.co.uk",
		"version"		=> "1.0",
		"guid" 			=> "",
		"compatibility" => "*"
	);
}

function limit_install()
{
	global $db;
	
	$query = $db->simple_select("settings", "COUNT(sid) as rows", "gid = '10'");
	$last_row = $db->fetch_field($query, 'rows');
	
	$set_one = array(
		"name" => "limitregdate",
		"title" => "Limit Joined Date",
		"description" => "Limit the Joined column to just show the date of registration. Administrators and Super-Mods can still see this information...",
		"optionscode" => "yesno",
		"value" => "1",
		"disporder" => $last_row+1,
		"gid" => "10"
	);
	$set_two = array(
		"name" => "limitlastvisit",
		"title" => "Limit Last Visit",
		"description" => "Limit the Last Visit column to just show the date of their last visit. Administrators and Super-Mods can still see this information...",
		"optionscode" => "yesno",
		"value" => "1",
		"disporder" => $last_row+2,
		"gid" => "10"
	);
	$set_three = array(
		"name" => "affectprofile",
		"title" => "Affect User Profile",
		"description" => "Limit the Last Visit in the User Profile too? Administrators and Super-Mods can still see this information...",
		"optionscode" => "yesno",
		"value" => "1",
		"disporder" => $last_row+3,
		"gid" => "10"
	);
		
		$db->insert_query("settings", $set_one);
		$db->insert_query("settings", $set_two);
		$db->insert_query("settings", $set_three);
	
	rebuild_settings();
}

function limit_uninstall()
{
	global $db;
	
	$db->delete_query("settings", "name='limitregdate'");
	$db->delete_query("settings", "name='limitlastvisit'");
	$db->delete_query("settings", "name='affectprofile'");
	
	rebuild_settings();
}

function limit_is_installed()
{
	global $db;
	$query = $db->simple_select("settings", "name", "name = 'limitregdate'");
	$exists = $db->fetch_field($query, 'name');
	if($exists)
 	{
 		return true;
	}
	return false;
}

function limit_activate()
{
	require_once MYBB_ROOT."inc/adminfunctions_templates.php";
	find_replace_templatesets('memberlist_user', '#'.preg_quote('regdate').'#', 'newregdate');
	find_replace_templatesets('memberlist_user', '#'.preg_quote('lastvisit').'#', 'newlastvisit');
}

function limit_deactivate()
{
	require_once MYBB_ROOT."inc/adminfunctions_templates.php";
	find_replace_templatesets('memberlist_user', '#'.preg_quote('newregdate').'#', 'regdate', 0);
	find_replace_templatesets('memberlist_user', '#'.preg_quote('newlastvisit').'#', 'lastvisit', 0);
}

function limit_mlist()
{
	global $user, $mybb, $lang;

if($mybb->usergroup['cancp'] == 1 || $mybb->usergroup['issupermod']){
		$regdate = my_date($mybb->settings['dateformat'], $user['regdate']).", ".my_date($mybb->settings['timeformat'], $user['regdate']);
	$lastvisit = my_date($mybb->settings['dateformat'], $user['lastactive']).", ".my_date($mybb->settings['timeformat'], $user['lastactive']);
		$user['newregdate'] = $regdate;
		$user['newlastvisit'] = $lastvisit;
	}
	else
	{
	if($mybb->settings['limitregdate'] == 1)
	{
		$regdate = my_date($mybb->settings['dateformat'], $user['regdate']);	
		if(strstr($regdate, "Today"))
		{
			$user['newregdate'] = $lang->today;
		}
		elseif(strstr($regdate, "Yesterday"))
		{
			$user['newregdate'] = $lang->yesterday;
		}
		else
		{
			$user['newregdate'] = $regdate;
		}
	}
	elseif($mybb->settings['limitregdate'] == 0)
	{
		$regdate = my_date($mybb->settings['dateformat'], $user['regdate']).", ".my_date($mybb->settings['timeformat'], $user['regdate']);
		$user['newregdate'] = $regdate;
	}
	
	if($mybb->settings['limitlastvisit'] == 1)
	{
		$lastvisit = my_date($mybb->settings['dateformat'], $user['lastactive']);
	
		if(strstr($lastvisit, "Today"))
		{
			$user['newlastvisit'] = $lang->today;
		}
		elseif(strstr($lastvisit, "Yesterday"))
		{
			$user['newlastvisit'] = $lang->yesterday;
		}
		else
		{
			$user['newlastvisit'] = $lastvisit;
		}
	}
	elseif($mybb->settings['limitlastvisit'] == 0)
	{
		$lastvisit = my_date($mybb->settings['dateformat'], $user['lastactive']).", ".my_date($mybb->settings['timeformat'], $user['lastactive']);
		$user['newlastvisit'] = $lastvisit;
	}
}
}

function limit_profile()
{
	global $mybb, $lang, $memlastvisitdate, $memlastvisittime;

if($memlastvisitdate != $lang->lastvisit_never)
{
	if($mybb->usergroup['cancp'] != 1 || $mybb->usergroup['issupermod'] != 1)
	{
		if($mybb->settings['affectprofile'])
		{
		if(strstr($memlastvisitdate, "Today"))
		{
			$memlastvisitdate = $lang->today;
			$memlastvisitsep = '';
			$memlastvisittime = '';		
		}elseif(strstr($memlastvisitdate, "Yesterday"))
		{
			$memlastvisitdate = $lang->yesterday;
			$memlastvisitsep = '';
			$memlastvisittime = '';				
		}
		else
		{
			$memlastvisitdate = my_date($mybb->settings['dateformat'], $memprofile['lastactive']);
			$memlastvisitsep = '';
			$memlastvisittime = '';	
		}
		}
	}
}
}
?>